==> geoportal-sdk-1.0.0.tgz: package/LICENCE.md <==

# Geoportal SDK

This software is released under the licence CeCILL-B (Free BSD compatible)

You may obtain a copy of the License at :

http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt (english)

http://www.cecill.info/licences/Licence_CeCILL-B_V1-fr.txt (french)

see http://www.cecill.info/

Copyright (c) 2016 IGN


## Third party code :

The Geoportal SDK includes the following third party code :

### OpenLayers

Copyright 2005-2017 OpenLayers Contributors. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY OPENLAYERS CONTRIBUTORS ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are those of the authors and should not be interpreted as representing official policies, either expressed or implied, of OpenLayers Contributors.


### Geoportal extension for OpenLayers

This software is released under the licence CeCILL-B (Free BSD compatible)

You may obtain a copy of the License at :

http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt (english)

http://www.cecill.info/licences/Licence_CeCILL-B_V1-fr.txt (french)

see http://www.cecill.info/

Copyright (c) 2016 IGN

See [Geoportal Extensions third party code licences](https://github.com/IGNF/geoportal-extensions/blob/master/LICENCE.md)

==> geoportal-sdk-1.2.0.tgz: package/LICENCE.md <==

# Geoportal SDK

This software is released under the licence CeCILL-B (Free BSD compatible)

You may obtain a copy of the License at :

http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt (english)

http://www.cecill.info/licences/Licence_CeCILL-B_V1-fr.txt (french)

see http://www.cecill.info/

Copyright (c) 2016 IGN


## Third party code :

The Geoportal SDK includes the following third party code :

### OpenLayers

Copyright 2005-2017 OpenLayers Contributors. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY OPENLAYERS CONTRIBUTORS ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are those of the authors and should not be interpreted as representing official policies, either expressed or implied, of OpenLayers Contributors.


### Geoportal extension for OpenLayers and Geoportal extension for iTowns

These softwares are released under the licence CeCILL-B (Free BSD compatible)

You may obtain a copy of the License at :

http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt (english)

http://www.cecill.info/licences/Licence_CeCILL-B_V1-fr.txt (french)

see http://www.cecill.info/

Copyright (c) 2016 IGN

See [Geoportal Extensions third party code licences](https://github.com/IGNF/geoportal-extensions/blob/master/LICENCE.md)
